/****************************************************************************
** QgsCopyrightLabelPluginGuiBase meta object code from reading C++ file 'pluginguibase.h'
**
** Created: Fri Nov 4 14:26:23 2005
**      by: The Qt MOC ($Id: qt/moc_yacc.cpp   3.3.4   edited Jan 21 18:14 $)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#undef QT_NO_COMPAT
#include "pluginguibase.h"
#include <qmetaobject.h>
#include <qapplication.h>

#include <private/qucomextra_p.h>
#if !defined(Q_MOC_OUTPUT_REVISION) || (Q_MOC_OUTPUT_REVISION != 26)
#error "This file was generated using the moc from 3.3.4. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

const char *QgsCopyrightLabelPluginGuiBase::className() const
{
    return "QgsCopyrightLabelPluginGuiBase";
}

QMetaObject *QgsCopyrightLabelPluginGuiBase::metaObj = 0;
static QMetaObjectCleanUp cleanUp_QgsCopyrightLabelPluginGuiBase( "QgsCopyrightLabelPluginGuiBase", &QgsCopyrightLabelPluginGuiBase::staticMetaObject );

#ifndef QT_NO_TRANSLATION
QString QgsCopyrightLabelPluginGuiBase::tr( const char *s, const char *c )
{
    if ( qApp )
	return qApp->translate( "QgsCopyrightLabelPluginGuiBase", s, c, QApplication::DefaultCodec );
    else
	return QString::fromLatin1( s );
}
#ifndef QT_NO_TRANSLATION_UTF8
QString QgsCopyrightLabelPluginGuiBase::trUtf8( const char *s, const char *c )
{
    if ( qApp )
	return qApp->translate( "QgsCopyrightLabelPluginGuiBase", s, c, QApplication::UnicodeUTF8 );
    else
	return QString::fromUtf8( s );
}
#endif // QT_NO_TRANSLATION_UTF8

#endif // QT_NO_TRANSLATION

QMetaObject* QgsCopyrightLabelPluginGuiBase::staticMetaObject()
{
    if ( metaObj )
	return metaObj;
    QMetaObject* parentObject = QDialog::staticMetaObject();
    static const QUMethod slot_0 = {"pbnOK_clicked", 0, 0 };
    static const QUMethod slot_1 = {"pbnCancel_clicked", 0, 0 };
    static const QUMethod slot_2 = {"btnFontColour_clicked", 0, 0 };
    static const QUMethod slot_3 = {"btnFontFace_clicked", 0, 0 };
    static const QUParameter param_slot_4[] = {
	{ 0, &static_QUType_bool, 0, QUParameter::In }
    };
    static const QUMethod slot_4 = {"cboxEnabled_toggled", 1, param_slot_4 };
    static const QUParameter param_slot_5[] = {
	{ 0, &static_QUType_QString, 0, QUParameter::In }
    };
    static const QUMethod slot_5 = {"cboOrientation_textChanged", 1, param_slot_5 };
    static const QUParameter param_slot_6[] = {
	{ 0, &static_QUType_QString, 0, QUParameter::In }
    };
    static const QUMethod slot_6 = {"cboPlacement_highlighted", 1, param_slot_6 };
    static const QUMethod slot_7 = {"languageChange", 0, 0 };
    static const QMetaData slot_tbl[] = {
	{ "pbnOK_clicked()", &slot_0, QMetaData::Public },
	{ "pbnCancel_clicked()", &slot_1, QMetaData::Public },
	{ "btnFontColour_clicked()", &slot_2, QMetaData::Public },
	{ "btnFontFace_clicked()", &slot_3, QMetaData::Public },
	{ "cboxEnabled_toggled(bool)", &slot_4, QMetaData::Public },
	{ "cboOrientation_textChanged(const QString&)", &slot_5, QMetaData::Public },
	{ "cboPlacement_highlighted(const QString&)", &slot_6, QMetaData::Public },
	{ "languageChange()", &slot_7, QMetaData::Protected }
    };
    metaObj = QMetaObject::new_metaobject(
	"QgsCopyrightLabelPluginGuiBase", parentObject,
	slot_tbl, 8,
	0, 0,
#ifndef QT_NO_PROPERTIES
	0, 0,
	0, 0,
#endif // QT_NO_PROPERTIES
	0, 0 );
    cleanUp_QgsCopyrightLabelPluginGuiBase.setMetaObject( metaObj );
    return metaObj;
}

void* QgsCopyrightLabelPluginGuiBase::qt_cast( const char* clname )
{
    if ( !qstrcmp( clname, "QgsCopyrightLabelPluginGuiBase" ) )
	return this;
    return QDialog::qt_cast( clname );
}

bool QgsCopyrightLabelPluginGuiBase::qt_invoke( int _id, QUObject* _o )
{
    switch ( _id - staticMetaObject()->slotOffset() ) {
    case 0: pbnOK_clicked(); break;
    case 1: pbnCancel_clicked(); break;
    case 2: btnFontColour_clicked(); break;
    case 3: btnFontFace_clicked(); break;
    case 4: cboxEnabled_toggled((bool)static_QUType_bool.get(_o+1)); break;
    case 5: cboOrientation_textChanged((const QString&)static_QUType_QString.get(_o+1)); break;
    case 6: cboPlacement_highlighted((const QString&)static_QUType_QString.get(_o+1)); break;
    case 7: languageChange(); break;
    default:
	return QDialog::qt_invoke( _id, _o );
    }
    return TRUE;
}

bool QgsCopyrightLabelPluginGuiBase::qt_emit( int _id, QUObject* _o )
{
    return QDialog::qt_emit(_id,_o);
}
#ifndef QT_NO_PROPERTIES

bool QgsCopyrightLabelPluginGuiBase::qt_property( int id, int f, QVariant* v)
{
    return QDialog::qt_property( id, f, v);
}

bool QgsCopyrightLabelPluginGuiBase::qt_static_property( QObject* , int , int , QVariant* ){ return FALSE; }
#endif // QT_NO_PROPERTIES
